***************************
* File: ecole.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\First Round\ecole_2e_jour\caisse.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "caisse", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "caisse", replace

**************************************************
***   Recode missing values
***************************************************
*    DECODE MISSING VALUES
# d ;
qui mvdecode   rsn_retard , mv(
5=.d);
# d cr;

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist jour  mois annee rsn_retard corresp plus differen cause mont_elv assurance coop_scol sport_sco act_art obligat total restant affiche endroit compta control fourn_cs livre_cs equip_cs frn_enft_cs nourri_cs entret_cs sal_ensg_cs depl_faf_cs depl_aut_cs mnt_elec_cs constr_cs gardien_cs dep_aut1_cs dep_aut2_cs reste_cs {
	gen error01`v' = (caisse_faf == 2 & `v'< . )
}

foreach v of varlist plus differen cause {
	gen error02`v' = (corresp== 1 & `v'< . )
}
gen error03endroit = ( affiche == 2 & endroit< . )

foreach v of varlist  fixe  mnt_fixe typ_fixe rembour levee fourn_fram livre_fram equip_fram enft_fram nourri_fram entre_fram sal_fram depl_faf_fr depl_aut_fr mnt_elec_fr constr_fram gard_fram dep_aut1_fr dep_aut2_fr reste_fram{
	gen error04`v' = (par_fram   == 2 & `v'< . )
}
foreach v of varlist    mnt_fixe typ_fixe {
	gen error05`v' = (fixe  == 2 & `v'< . )
}
foreach v of varlist   man_06- cim_aut {
	gen error06`v' = (cp2_exist  == 2 & `v'< . )
}


**************************************************
***  Identify illegal responses
**************************************************
log using "caisse label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
log using "caisse grubbs", replace
preserve
global lab (	non_07	non_06	cause	plus	fenetre	toit	murs	plancher	rec_man_07	rec_man_06	rec_kit_07	rec_kit_06	typ_fixe	endroit	rsn_retard	man_07	man_06	cp2_exist	kits_07	kits_06	fram_nat	levee	rembour	fixe	par_fram	control	compta	affiche	corresp	caisse_faf	ec_ferme)
global name (  autre1_cs autre2_cs aut1_fram aut2_fram)
drop  $lab $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore


**************************************************
***   Reviewing errors and computing responses
**************************************************
replace caisse_faf=1 if codecole==1060921
replace fixe=. if codecole==2071321
replace fixe=. if codecole==4020222
replace par_fram=1 if codecole==2070323
replace rembour=. if codecole==1031722
replace rembour=. if codecole==1125522
replace rembour=. if codecole==4131323
replace levee=. if codecole==2071321
replace levee=. if codecole==1031722
replace levee=. if codecole==1125522
replace levee=. if codecole==4131323

replace levee=. if codecole==1121621
replace levee=. if codecole==2134323
replace levee=. if codecole==5190121
replace levee=. if codecole==5191722
replace par_fram=1 if codecole==4080321
replace par_fram=1 if codecole==1031721

replace reste_fram=. if codecole==2134121

replace man_06=. if codecole==1141921
replace man_06=. if codecole==1141922
replace man_06=. if codecole==1142322
replace man_06=. if codecole==1142323
replace man_06=. if codecole==2161721
replace man_06=. if codecole==3080323
replace man_06=. if codecole==4130222
replace man_06=. if codecole==7190622
replace cp2_exist=1 if codecole==7190622
replace cp2_exist=1 if codecole==2060123
replace non_06=. if codecole==1142322
replace non_06=. if codecole==3080323
replace non_06=. if codecole==4130222

replace man_07=. if codecole==1142322
replace man_07=. if codecole==3080323
replace cp2_exist=1 if codecole==4130222

replace non_07=. if codecole==1142322
replace non_07=. if codecole==3080323

 
 foreach v of varlist   craie_cisco- cim_aut {
	replace `v' = . if codecole==1142322 | 3080323
}


drop error* 

**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\ecole_2e_jour"
log using "caisse codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\ecole_2e_jour"
save "caisse_cleaned_data.dta", replace
