***************************
* File: ecole.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\First Round\ecole_2e_jour\ecole.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "ecole", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "ecole", replace


**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 
gen error01critere = (refus_cp1 == 2 & critere< . )
gen error02nb_vis_cisco = (vis_cisco == 2 & nb_vis_cisco< . )

foreach v of varlist      nb_mb_fram reun_fram nb_parent nb_coge coge_femme {
	gen error03`v' = (fram == 2 & `v'< . )
}
 gen error04elec_fonc = (elec == 2 & elec_fonc< . )
gen error05toil_sep = (toilet == 2 & toil_sep< . )
gen error06nb_assis = (assis == 2 & nb_assis< . )
gen error07nb_pleinair = (plein_air == 2 & nb_pleinair< . )

**************************************************
***  Identify other internal coherence issues
**************************************************
	gen inc01critere = (refus_cp1 == 2 & critere< . )

	gen inc02 = ( gar_pre_06+fil_pre_06 != tot_pre_06 & tot_pre_06 !=0 )
	gen inc03 = ( gar_cp1_06+fil_cp1_06!= tot_cp1_06 & tot_cp1_06 !=0 & (gar_cp1_06< . & fil_cp1_06< .)  )
	gen inc04 = ( gar_cp2_06+fil_cp2_06!= tot_cp2_06 & tot_cp2_06 !=0 & (gar_cp2_06< . & fil_cp2_06< .))
	gen inc05 = ( gar_ce_06+fil_ce_06!= tot_ce_06 & tot_ce_06 !=0& (gar_ce_06< . & fil_ce_06< .))
	gen inc06 = ( gar_cm1_06+fil_cm1_06!= tot_cm1_06 & tot_cm1_06 !=0& (gar_cm1_06< . & fil_cm1_06< .))
	gen inc07 = ( gar_cm2_06+fil_cm2_06!= tot_cm2_06 & tot_cm2_06 !=0& (gar_cm2_06< . & fil_cm2_06< .))

	gen inc08 = ( gar_pre_07+fil_pre_07 != tot_pre_07 & tot_pre_07 !=0 )
	gen inc09 = ( gar_cp1_07+fil_cp1_07!= tot_cp1_07 & tot_cp1_07 !=0 & (gar_cp1_07< . & fil_cp1_07< .)  )
	gen inc10 = ( gar_cp2_07+fil_cp2_07!= tot_cp2_07 & tot_cp2_07 !=0 & (gar_cp2_07< . & fil_cp2_07< .))
	gen inc11 = ( gar_ce_07+fil_ce_07!= tot_ce_07 & tot_ce_07 !=0& (gar_ce_07< . & fil_ce_07< .))
	gen inc12 = ( gar_cm1_07+fil_cm1_07!= tot_cm1_07 & tot_cm1_07 !=0& (gar_cm1_07< . & fil_cm1_07< .))
	gen inc13 = ( gar_cm2_07+fil_cm2_07!= tot_cm2_07 & tot_cm2_07 !=0& (gar_cm2_07< . & fil_cm2_07< .))

**************************************************
***  Identify illegal responses
**************************************************
log using "ecole label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
log using "ecole grubbs", replace
preserve
global lab (assis	unit_reun	elev_math	elev_fran	elev_malg	diction	livre	methode	eval_fram	eval_fonc	renvoi_fram	renvoi_fonc	sanc_fram3	sanc_fram2	sanc_fram1	sanc_fonc3	sanc_fonc2	sanc_fonc1	reco_fram3	reco_fram2	reco_fram1	reco_fonc3	reco_fonc2	reco_fonc1	prog_ensgt	critere	plein_air	eau_pot	sport	cantine	toil_sep	toilet	infirm	salle_ensgt	biblio	bur_dir	elec_fonc	elec	fram	vis_dren	vis_cisco	refus_cp1	tps_part	mitps	plein	normal	multigr	ec_ferme	)
global name ( autre1_06 autre2_06 autre1_07)
drop  $lab $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
***   Reviewing errors and computing responses
**************************************************
replace nb_assis=. if codecole ==7162922 | codecole ==7162721	
replace assis=1 if codecole ==2161723

*incoherence
replace tot_cp1_06=59 if codecole==7190623
replace tot_cp2_06= 123 if codecole==4091423
replace tot_cp2_06= 54 if codecole==5111921
replace tot_ce_06= 26 if codecole==5110122
replace tot_ce_06= 28 if codecole==5145522
replace tot_ce_06= 31 if codecole==7191923
replace tot_cm1_06= 128 if codecole==3019926
replace tot_cm2_06= 31 if codecole==2041923
replace tot_cm2_06= 21 if codecole==4091423

replace tot_cp1_07=39 if codecole==3080223
replace tot_cp1_07=15 if codecole==4081121
replace tot_cp1_07=22 if codecole==7190421
replace tot_cp2_07=38 if codecole==1141921
replace tot_cp2_07=39 if codecole==4091122
replace tot_cp2_07=19 if codecole==5121521
replace tot_cp2_07=77 if codecole==5121523
replace tot_cp2_07=93 if codecole==5145523
replace tot_ce_07=21 if codecole==2060721
replace tot_ce_07=46 if codecole==3040622
replace tot_ce_07=27 if codecole==7162721

replace tot_cm1_07=34 if codecole==1120523
replace tot_cm1_07=41 if codecole==1141923
replace tot_cm2_07=89 if codecole==1030723
replace tot_cm2_07=62 if codecole==7190623


*illegal responses
replace vis_dren=2 if codecole==5146621

drop error* inc*

**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\ecole_2e_jour"
log using "ecole codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\ecole_2e_jour"
save "ecole_cleaned_data.dta", replace
